
/*
Cumulated Allbus 

- sex
- Children yes/no
- Number of biological children
- Educational level
- Birth date / Cohort
- Born in Germany
- where lived before reunification
- interview date
- weights
*/
set more off

use "${data_allbus_cumulated}", clear

rename V653 sex
recode V649 (9997 9998 9999 = .)
rename V649 birth
rename V2 syear
recode V651 (997 998 999 = .)
rename V651 age

// asked only 82 84, 91, 92
recode V1345 (99 = .a) (96 = .) // Anzahl Kinder
// tab syear V1345, miss

gen nofchildren = V1345

// number of biological children (asked: 2000-2012)
recode V1346 (99 = .a) (96 = .)
// 
tab syear V1346, miss

// ANZAHL LEIBL., STIEF. + ADOP. KINDER (2000-12)
recode V1348 (99 = .a) (96 = .)
tab syear V1348, miss

replace nofchildren = V1348 if V1348!=.

// education - school
recode V668 (99 = .)

// training
recode V671 (97 99 = .b) (0 = .) // 1980-1990


// 86 +
d V675  V676 V677 V678 V679 V680 V681 V682 V683 V684 V685 V686
recode V675  V676 V677 V678 V679 V680 V681 V682 V683 V684 V685 V686 (6 = .) (9 = .a)

// Teilfacharbeiter (no training) 
// Fachschulabschluss (-> berufsausbildung, wie Meister) 

// recode 1980-90
recode V671 (1 9 5 = 1 "kein Abschluss") (2 3 4 6 = 2 "Lehre/meister") (7 = 3 "FH") (8 = 4 "Uni"), gen(voc)

gen voc_2 = .
d V675  V676 V677 V678 V679 V680 V681 V682 V683 V684 V685 V686
replace voc_2 = 1 if V675==1 | V676 == 1 | V677 == 1 | V680 == 1 | V686 == 1
replace voc_2 = 2 if V678 == 1 | V679 == 1 | V681 == 1 | V682 == 1 | V683 == 1 
replace voc_2 = 3 if V684 == 1
replace voc_2 = 4 if V685==1

replace voc = voc_2 if mi(voc) & !mi(voc_2)

recode V668 (1 7  = 1 "kein Abschluss") ///
		   (2  = 2 "HS" ) ///
		   (3  = 3 "RS")  ///
		   (4 5 = 4 "ABI") ///
		   (6 = 5 "sonstiges") ///
		   (-1 = .) ///
		   , gen(CASMIN_gen)

recode voc (1 = 1 "keine BA") ///
		   (2 = 2 "BA") ///
		   (3 = 3 "FH") ///
		   (4 = 4 "Uni") ///
		   , gen(CASMIN_voc)
		   
// combine
gen CASMIN = -1
lab def CASMIN ///
9 "3b Hochschulabschluss" ///
8 "3a Fachhochschulabschluss" ///
7 "2c_voc Fachhochschulreife/Abitur und berufliche Ausbildung" ///
6 "2c_gen Fachhochschulreife/Abitur ohne berufliche Ausbildung" ///
5 "2a Mittlere Reife und berufliche Ausbildung" ///
4 "2b Mittlere Reife ohne berufliche Ausbildung" ///
3 "1c Hauptschulabschluss und berufliche Ausbildung" ///
2 "1b Hauptschulabschluss ohne berufliche Ausbildung" ///
1 "1a kein Abschluss" ///
.b "nicht bestimmbar" ///
, modify

lab val CASMIN CASMIN
replace CASMIN = 9 if CASMIN_voc == 4
replace CASMIN = 8 if CASMIN_voc == 3
replace CASMIN = 7 if CASMIN_voc == 2 & CASMIN_gen == 4
replace CASMIN = 6 if CASMIN_voc == 1 & CASMIN_gen == 4
replace CASMIN = 5 if CASMIN_voc == 2 & CASMIN_gen == 3
replace CASMIN = 4 if CASMIN_voc == 1 & CASMIN_gen == 3
replace CASMIN = 3 if CASMIN_voc == 2 & CASMIN_gen == 2
replace CASMIN = 2 if CASMIN_voc == 1 & CASMIN_gen == 2
replace CASMIN = 1 if CASMIN_voc == 1 & CASMIN_gen == 1
// special cases: 
// no school degree but BA => define as "HS mit BA"
replace CASMIN = 3 if CASMIN_gen==1 & CASMIN_voc==2 & CASMIN==-1
// other school degree and BA => define as "HS mit BA"
replace CASMIN = 3 if CASMIN_gen==5 & CASMIN_voc==2 & CASMIN==-1
/*
// "die Schule ohne Abschluss verlassen" & 
// "die Pflichtschule mit Abschluss beendet" => dito
replace CASMIN = 3 if inlist(x28,1,2) & CASMIN_voc==2 & CASMIN==-1
// "eine weiterführende Schule mit Abschluss beendet" => RS + BA
replace CASMIN = 5 if inlist(x28,3) & CASMIN_voc==2 & CASMIN==-1
// "weiß nicht / verweigert" => assign Hauptschule!
*/
replace CASMIN = 3 if mi(CASMIN_gen) & CASMIN_voc==2 & CASMIN==-1

/*
// keine BA & kein schulabschluss
replace CASMIN = 1 if x28==1 & CASMIN_voc==1 & CASMIN==-1
replace CASMIN = 2 if x28==2 & CASMIN_voc==1 & CASMIN==-1
replace CASMIN = 4 if x28==3 & CASMIN_voc==1 & CASMIN==-1

// sonstige Ausbildung (kodiere als keine Berufsausbildung)
replace CASMIN = 1 if x28==1 & x31==5 & CASMIN==-1
replace CASMIN = 2 if x28==2 & x31==5 & CASMIN==-1
replace CASMIN = 4 if x28==3 & x31==5 & CASMIN==-1
*/

replace CASMIN = 1 if CASMIN_gen == 1 & CASMIN_voc == 5 & CASMIN == -1
replace CASMIN = 2 if CASMIN_gen == 2 & CASMIN_voc == 5 & CASMIN == -1
replace CASMIN = 4 if CASMIN_gen == 3 & CASMIN_voc == 5 & CASMIN == -1
replace CASMIN = 6 if CASMIN_gen == 4 & CASMIN_voc == 5 & CASMIN == -1

// if ausbildung was skipped
replace CASMIN = 1 if CASMIN_gen == 1 & mi(CASMIN_voc) & CASMIN == -1
replace CASMIN = 2 if CASMIN_gen == 2 & mi(CASMIN_voc) & CASMIN == -1
replace CASMIN = 2 if CASMIN_gen == 2 & mi(CASMIN_voc) & CASMIN == -1
replace CASMIN = 4 if CASMIN_gen == 3 & mi(CASMIN_voc) & CASMIN == -1
replace CASMIN = 6 if CASMIN_gen == 4 & mi(CASMIN_voc) & CASMIN == -1

/*
replace CASMIN = 1 if x28==1 & x31==-1 & CASMIN==-1
replace CASMIN = 2 if x28==2 & x31==-1 & CASMIN==-1
replace CASMIN = 4 if x28==3 & x31==-1 & CASMIN==-1
replace CASMIN = 4 if inlist(x28,8,9) & x31==-1 & CASMIN==-1
*/
/*
// kein schulbesuch
replace CASMIN = 1 if x26==6 & CASMIN==-1
*/

// set rest to not determinable
replace CASMIN = .b if CASMIN==-1

drop CASMIN_*

lab var CASMIN "CASMIN-classes"
fre CASMIN

recode CASMIN (1 2 4 = 0 "low") /// no degree, hauptschule ohne BA, realschule ohne BA
		   (3 = 1 "lower voc") /// hauptschule mit BA
		   (5 =2 "medium voc") /// realschule mit BA
		   (6 7 = 3 "high voc") /// abitur +/- BA
		   (8 9  = 4 "university") /// tertiary, university
		   , gen(E)
// collapse high voc and university
capt drop E
recode CASMIN (1 2 4 = 0 "low") /// no degree, hauptschule ohne BA, realschule ohne BA
		   (3 = 1 "lower voc") /// hauptschule mit BA
		   (5 =2 "medium voc") /// realschule mit BA
		   (6 7 8 9 = 3 "high voc/university") /// abitur +/- BA, tertiary, university
		   , gen(E)	
		   
// fertility / parenting data only available for 82,84,91,92,2000-12
tabstat nofchildren , by(syear)

// drop other surveys
drop if inlist(syear, 1980,1986,1988,1990,1994,1996,1998)

// East / west (interview location)
recode V5 (1 = 2 "West") (2=1 "East"), gen(part)
rename V4 id

// place of birth (only 91+)
recode V1191  (0 = .) (9=.a)
gen borninde = V1191==1 if !mi(V1191)
replace borninde = -1 if V1191==.
// no data on place of birth before 1991
// substitute with german citizenship
recode V6 (9 = .a)
rename V6 gercit

// weights
replace V1739 = . if V1739 > 9 
replace V1740 = . if V1740 > 9 
replace V1741 = . if V1741 > 9 

keep id sex birth nofchildren CASMIN E syear age part borninde gercit V1739  V1740 V1741 
 

save "${tempDir}/00_kum_Allbus.dta", replace

exit





