/*
Prepare data from DEAS 2002

Variables needed: 

- sex
- Children yes/no
- Number of biological children
- Educational level
- Birth date / Cohort
- Born in Germany
- where lived before reunification
- interview date
- weights

- stichprobe (update 1996 sample by panel data) -> stich
- part_96


Sample information ( Engstler &  Lejeune 2014, Kurzbeschreibung DEAS): 
- Welle 2 (2002) wurden für die Basiserhebung zwei getrennte Stichproben von Deutschen und Nicht-Deutschen gezogen.
- Erstmals befragte Deutsche der Geburts- jahrgänge 1917-1962; diese sind 40 bis 85 Jahre alt1
- Panel and Basisstichprobe
*/


use ${data_deas_2002}, clear
lab lang de

// kick foreigners sample
drop if stich==0 // no igew_7 (Anpassungsgewichte) for foreigner sample

//  4.608
count


rename w1_11 sex 

rename w1_16 birth

rename w25_11 geburtsort

recode w18_1370 (95 = 0), gen(nofchildren)


// up to child 8 is asked
gen numbiochild = 0 // number of reported biological children
foreach num of numlist 19/22 72/75 {
	replace numbiochild = numbiochild + 1 if w`num'_31 == 1
}

/*
w19_31 family relationship
w19_32 child birth
w19_36 living?
w19_137 child died when?
*/
// Note: number of reported bio children may be biased towards zero since 
//       not specified missings in family relationship are treated as non-bio child.

// Living biological children (i.e. children who are still living or lived at least to 20)
gen numbiochildliv = 0 
foreach num of numlist 19/22 72/75 {
	replace numbiochildliv = numbiochildliv + 1 if w`num'_31 == 1 & (w`num'_36==1 | (w`num'_36==2 & (w`num'_32 -  w`num'_137)>=20))
}
// Schulabschluss 
// Ausbildungsabschluss 
// Variables
d w13_11 w13_14 w13_15 w13_68 w13_69 w13_70 w13_142
// ACHTUNG: AUCH HIER ABWEICHUNGEN ZUM CODEBOOK! 
// schulabschluss
fre w13_14 if w13_15 == .c // überfiltert (Frage) in höchster Schulanschluss für die die im Ausland die Schule abgeschlossen haben


// RULE:
recode w13_15 (1 9 = 1 "kein Abschluss") ///
		   (2 4 = 2 "HS" ) ///
		   (3 5 = 3 "RS")  ///
		   (6 7 = 4 "ABI") ///
		   (8 = 5 "sonstiges") ///
		   , gen(CASMIN_gen)

// Teil|fach|ar|bei|ter, der (DDR): angelernter Arbeiter 
// (ohne abgeschlossene Ausbildung).
// Teilfacharbeiter => keine Ausbildung, eher Lehrgang

// ACHTUNG: Datenfehler in v4_13 => code .c bedeutet Hochschulabschluss!!!
// siehe codebook
recode w13_70 (1 8 = 1 "keine BA") ///
		   (2 3 4 = 2 "BA") ///
		   (5 = 3 "FH") ///
		   (6 = 4 "Uni") ///
		   (7 = 5 "sonstiges") ///
		  , gen(CASMIN_voc)
	  
replace CASMIN_voc = 1 if w13_142==1 & CASMIN_voc >= .
replace CASMIN_voc = 2 if w13_142==2 & CASMIN_voc >= .
replace CASMIN_voc = 2 if w13_142==3 & CASMIN_voc >= .
replace CASMIN_voc = 3 if w13_142==4 & CASMIN_voc >= .


// combine
gen CASMIN = -1
lab def CASMIN ///
9 "3b Hochschulabschluss" ///
8 "3a Fachhochschulabschluss" ///
7 "2c_voc Fachhochschulreife/Abitur und berufliche Ausbildung" ///
6 "2c_gen Fachhochschulreife/Abitur ohne berufliche Ausbildung" ///
5 "2a Mittlere Reife und berufliche Ausbildung" ///
4 "2b Mittlere Reife ohne berufliche Ausbildung" ///
3 "1c Hauptschulabschluss und berufliche Ausbildung" ///
2 "1b Hauptschulabschluss ohne berufliche Ausbildung" ///
1 "1a kein Abschluss" ///
.b "nicht bestimmbar" ///
, modify

lab val CASMIN CASMIN
replace CASMIN = 9 if CASMIN_voc == 4
replace CASMIN = 8 if CASMIN_voc == 3
replace CASMIN = 7 if CASMIN_voc == 2 & CASMIN_gen == 4
replace CASMIN = 6 if CASMIN_voc == 1 & CASMIN_gen == 4
replace CASMIN = 5 if CASMIN_voc == 2 & CASMIN_gen == 3
replace CASMIN = 4 if CASMIN_voc == 1 & CASMIN_gen == 3
replace CASMIN = 3 if CASMIN_voc == 2 & CASMIN_gen == 2
replace CASMIN = 2 if CASMIN_voc == 1 & CASMIN_gen == 2
replace CASMIN = 1 if CASMIN_voc == 1 & CASMIN_gen == 1
// special cases: 
// no school degree but BA => define as "HS mit BA"
replace CASMIN = 3 if CASMIN_gen==1 & CASMIN_voc==2 & CASMIN==-1
// other school degree and BA => define as "HS mit BA"
replace CASMIN = 3 if CASMIN_gen==5 & CASMIN_voc==2 & CASMIN==-1

// "die Schule ohne Abschluss verlassen" & 
// "die Pflichtschule mit Abschluss beendet" => dito
replace CASMIN = 3 if inlist( w13_68,1,2) & CASMIN_voc==2 & CASMIN==-1
// "eine weiterführende Schule mit Abschluss beendet" => RS + BA
replace CASMIN = 5 if inlist( w13_68,3) & CASMIN_voc==2 & CASMIN==-1
// "weiß nicht / verweigert" => assign Hauptschule!

replace CASMIN = 3 if mi(CASMIN_gen) & CASMIN_voc==2 & CASMIN==-1


// keine BA & kein schulabschluss
replace CASMIN = 1 if w13_68==1 & CASMIN_voc==1 & CASMIN==-1
replace CASMIN = 2 if w13_68==2 & CASMIN_voc==1 & CASMIN==-1
replace CASMIN = 4 if w13_68==3 & CASMIN_voc==1 & CASMIN==-1

// sonstige Ausbildung (kodiere als keine Berufsausbildung)
replace CASMIN = 1 if w13_68==1 & w13_142==5 & CASMIN==-1
replace CASMIN = 2 if w13_68==2 & w13_142==5 & CASMIN==-1
replace CASMIN = 4 if w13_68==3 & w13_142==5 & CASMIN==-1


replace CASMIN = 1 if CASMIN_gen == 1 & CASMIN_voc == 5 & CASMIN == -1
replace CASMIN = 2 if CASMIN_gen == 2 & CASMIN_voc == 5 & CASMIN == -1
replace CASMIN = 4 if CASMIN_gen == 3 & CASMIN_voc == 5 & CASMIN == -1
replace CASMIN = 6 if CASMIN_gen == 4 & CASMIN_voc == 5 & CASMIN == -1

// if ausbildung was skipped
replace CASMIN = 1 if CASMIN_gen == 1 & mi(CASMIN_voc) & CASMIN == -1
replace CASMIN = 2 if CASMIN_gen == 2 & mi(CASMIN_voc) & CASMIN == -1
replace CASMIN = 2 if CASMIN_gen == 2 & mi(CASMIN_voc) & CASMIN == -1
replace CASMIN = 4 if CASMIN_gen == 3 & mi(CASMIN_voc) & CASMIN == -1
replace CASMIN = 6 if CASMIN_gen == 4 & mi(CASMIN_voc) & CASMIN == -1

/*
replace CASMIN = 1 if x28==1 & x31==-1 & CASMIN==-1
replace CASMIN = 2 if x28==2 & x31==-1 & CASMIN==-1
replace CASMIN = 4 if x28==3 & x31==-1 & CASMIN==-1
replace CASMIN = 4 if inlist(x28,8,9) & x31==-1 & CASMIN==-1
*/
// kein schulbesuch
replace CASMIN = 1 if w13_11==995 & CASMIN==-1

// set rest to not determinable
replace CASMIN = .b if CASMIN==-1

// panel sample (for those education was not asked again) gets special code
replace CASMIN = .d if w13_11==.d

drop CASMIN_*

lab var CASMIN "CASMIN-classes"
fre CASMIN

recode CASMIN (1 2 4 = 0 "low") /// no degree, hauptschule ohne BA, realschule ohne BA
		   (3 = 1 "lower voc") /// hauptschule mit BA
		   (5 =2 "medium voc") /// realschule mit BA
		   (6 7 = 3 "high voc") /// abitur +/- BA
		   (8 9  = 4 "university") /// tertiary, university
		   , gen(E)
// collapse high voc and university
capt drop E
recode CASMIN (1 2 4 = 0 "low") /// no degree, hauptschule ohne BA, realschule ohne BA
		   (3 = 1 "lower voc") /// hauptschule mit BA
		   (5 =2 "medium voc") /// realschule mit BA
		   (6 7 8 9 = 3 "high voc/university") /// abitur +/- BA, tertiary, university
		   , gen(E)	

recode birth 	(1914/1925.9 = 1 "1914-1926)") ///
			    (1926/1935.9 = 2 "1926-1936)") /// 
				(1936/1944.9 = 3 "1936-1945)") ///
				(1945/1960 = 4 "1945-1960") ///
				(else = .), gen(Chrt)		  

// collapse cohort categories
recode Chrt (1 2 = 1) (3 4 = 2),  gen(Chrt2) 

// usual residence last 40 years
rename w25_48 res19491990 		   

keep fallnum igew_7 intmonat intjahr stich part_96 igew_7 westost_02 bland_02 alter_02 sex E CASMIN ///
		birth Chrt Chrt2 nofchildren numbiochild numbiochildliv geburtsort	res19491990	 isced_02
		
gen DEAS = 2002

save "${tempDir}/00_DEAS-2002.dta", replace		
