/*------------------------------------------------------------------------------
  ------------------------------------------------------------------------------
  Skopek, Jan and Leopold, Thomas (2020). Educational Reproduction in Germany: 
  A Prospective Study Based on Retrospective Data. In: Demography.
  
  PROJECT MASTER FILE
 
  The syntax of the empirical analysis is divided into sub-files, each 
  of which completes a specific step in the analysis. 
  
  This master file runs each of these steps in the right order. 
  You can run the complete analysis by executing this file.
 
  The syntax for the project is split into the following steps:
  
  0-X) DATA PREPARATION 
  
	0-0) Preparing retrospective survey data (NEPS and SOEP)
  
	0-1) Preparing fertility data (for estimating childlessness)
  
	0-2) Fusing retrospective and zero-fertility data 
	
	0-3) Defining starting samples of NEPS and SOEP respondents
	
	0-4) Creating parent samples
  
  1-0) DATA ANALYSIS 
  
		Rates of educational reproduction, decomposition analysis, and 
		scenario analyses based on population renewal models. 
	   
 
  Detailed documentation can be found in the respective sub-files. 
  
  The configuration file 'config.do' defines important 
  settings (= paths) as well as various programs needed for the analysis. 
  Before executing any other do-file, this file should always run first. 

------------------------------------------------------------------------------
------------------------------------------------------------------------------*/

// call the configuration file
run config 	

/*------------------------------------------------------------------------------
 ------------------------------------------------------------------------------
 
 0-X) DATA PREPARATION 
 
 ------------------------------------------------------------------------------
------------------------------------------------------------------------------*/

/*------------------------------------------------------------------------------
 0-0) Preparing retrospective survey data from SOEP and NEPS 
      (SOEP v.32, NEPS v. 5.1.0)
------------------------------------------------------------------------------*/
do 00_retrospective_data.do

/*------------------------------------------------------------------------------
 0-1) Preparing fertility data
------------------------------------------------------------------------------*/
do 01_fertility_data.do

/*------------------------------------------------------------------------------
 0-2) Fusing retrospective and zero-fertility data 
 
	Outputs:
	 Table B1
------------------------------------------------------------------------------*/
do 02_data_fusion.do

/*------------------------------------------------------------------------------
 0-3) Defining starting samples of NEPS and SOEP respondents
 
	  Outputs: 
	  - Figure A1
	  - Table 1
------------------------------------------------------------------------------*/
do 03_startingsample_respondents.do

/*------------------------------------------------------------------------------
 0-4) Creating parent samples
 
	  Outputs: 
	  - Figures 2, A2, A3
	  - Table 2
------------------------------------------------------------------------------*/
do 04_parent_samples.do


/*------------------------------------------------------------------------------
 ------------------------------------------------------------------------------
 
 1-0) DATA ANALYSIS 
	
	  Educational reproduction
	  
	  (A) Estimating rates of educational reproduction and decomposition analysis. 
	  +
	  (B) Scenario analyses based on population renewal models
	  
	  Outputs: 
	  - Figures 1,3,4,5,and 6
	  - Tables 3, B2, B3, B4, B5, B6, B7, and B8
 ------------------------------------------------------------------------------
------------------------------------------------------------------------------*/
do 10_educational_reproduction.do
