/**********************************************************************
* 
* Leopold, Thomas and Skopek, Jan (2015). Convergence or Continuity? 
* The Gender Gap in Household Labor After Retirement. In: Journal of 
* Marriage and Family.
*
*
* Configuration file
* 
**********************************************************************/

clear				
version 15.1 			// stata version 15.1
capt log close _all		// close all log files


/******* Config *******/

global workingDir "`c(pwd)'"	// working directory (set to current working directory)

global data_neps "/Users/janskopek/Dropbox/PROJEKTE/Daten/NEPS/SC6/SC6_D_5-1-0/Stata" // path to NEPS SC6 data 


* References to data files: 

* Retrospective social mobility data (directories)
* Note: SOEP v.32 was available in long and wide versions. We used data from both. 
global data_soep_long "/Users/janskopek/Dropbox/PROJEKTE/Daten/SOEP/soep_v32/long" // path to SOEP long data 
global data_soep_wide "/Users/janskopek/Dropbox/PROJEKTE/Daten/SOEP/soep_v32/core_wide/" // path to SOEP wide data 

* External fertility data (file paths)
global data_allbus_cumulated "../../DEAS-Data/ZA4578_v1-0-0.dta" // Cumulated ALLBUS, ZA4578_v1
global data_allbus_2014 	 "../../DEAS-Data/ZA5240_v2-1-0.dta" // ALLBUS 2014, ZA5240_v2

global data_deas_1996 		 "../../DEAS-Data/SUF_DEAS1996_2_1_deen_Stata-2.dta" // DEAS, SUF_DEAS1996_2_1_deen_Stata-2
global data_deas_2002 		 "../../DEAS-Data/SUF_DEAS2002_2_deen_Stata-2.dta" // DEAS, SUF_DEAS2002_2_deen_Stata-2
global data_deas_2008		 "../../DEAS-Data/SUF_DEAS2008_2_deen.dta" // DEAS, SUF_DEAS2008_2_deen 
global data_deas_2011 		 "../../DEAS-Data/SUF_DEAS2011_1_deen_Stata-2.dta" // DEAS, SUF_DEAS2011_1_deen_Stata-2
* We used an additional file for DEAS 2008 and 2011, that contained detailed birth dates on children and grandchildren 
* (the standard scientific use files contained coarsened dates for higher data anonymity). 
* This file was specially provided by DEAS Data Center to us. 
* However, this file is not essential for the analysis. 
global data_deas_2008_exact_birthdates "../../DEAS-Data/DEAS2008_Geburtsjahre_Kinder+Enkel.dta"
global data_deas_2011_exact_birthdates "../../DEAS-Data/DEAS2011_Geburtsjahre_Kinder+Enkel.dta"

global data_ess "../../DEAS-Data/ESS3e03_4.dta" // ESS, ESS3e03_4

/**********************/

/*** do not edit here ***/
global tempDir 		= "${workingDir}/temp"		// directory for temporary data files
global logDir		= "${workingDir}/log-files"	// directory for log files
global adoDir		= "${workingDir}/ado"
cd "$workingDir" 			// change to working directory
adopath + "$adoDir" 		// extend the ado-file search path
capt mkdir "$tempDir" 		// create directory for temporary files (if not there)
capt mkdir "$logDir" 		// create directory for log files (if not there)
/*** do not edit here (end) ***/

set varabbrev off	// turn off stata's akward feature of abbreviating variable names
set more off		// turn off the "more"
global config = 1	// a flag that config file was executed already


/*** programs ***/


